==> phplist-2.10.5p0.tgz: lists/admin/lan/es/admin.php <==
<?php

$lan = array(
  'listofadministrators' => 'Lista de administradores',
'Add a new Administrator' => 'A&ntilde;adir administrador',
  'No Access' => 'Sin acceso',
  'Changes saved' => 'Cambios salvados',
  'Error adding new admin' => 'Error al a&ntilde;adir nuevo administrador',
  'strAccessExplain' => '<hr/>
<p>Establecer permisos de acceso a p&aacute;ginas en el sistema:</p>
<ul>
<li>Todos: el administrador tiene acceso a la p&aacute;gina sin restricciones.</li>
<li>Ver: el administrador puede ver la p&aacute;gina, pero no puede cambiar nada. De momento esto solo funciona en las p&aacute;ginas «usuario», «usuarios» y «miembros».</li>
<li>Ninguno: el administrador no puede ver esta p&aacute;gina.</li>
<li>Due&ntilde;o: el administrador puede ver esta p&aacute;gina, pero solo puede ver el contenido de aquellas listas de las que es el due&ntilde;o.</li>
</ul>
',
'Edit Administrator' => 'Editar administrador',
'Admin Details' => 'Detalles de administrador',
'ID' => 'ID',
'Login Name' => 'Nombre de usuario',
'Normalised loginname' => 'Nombre de usuario normalizado',
'Email' => 'Email',
'Time Created' => 'Creado',
'Time modified' => 'Modificado',
'Modified by' => 'Modificado por',
'Last time password was changed' => '&Uacute;ltima vez que se cambi&oacute; la contrase&ntilde;a',
'Is this user Super Admin?' => '&#191;Es superadministrador este usuario?',
'Is this account disabled?' => '&#191;Est&aacute; deshabilitada esta cuenta?',
'Save Changes' => 'Salvar cambios',
'Current set of permissions made default' => 'Se ha establecido la configuraci&oacute;n de
  permisos actual como configuraci&oacute;n por defecto',
'Done' => 'Listo',
'OK' => 'OK',
'Deleting' => 'Borrando',
'Login Name (max 25 chars)' => 'Nombre de usuario (m&aacute;ximo 25 caracteres)',
'Access Details' => 'Ver detalles',
'Access Privileges' => 'Ver privilegios',
'Type' => 'Tipo',
'Page' => 'P&aacute;gina',
'Set these permissions as default' => 'Establecer esta configuraci&oacute;n de permisos como configuraci&oacute;n por defecto',
'Reset to Default' => 'Volver a la configuraci&oacute;n por defecto',
'none' => 'ninguno',
'all' => 'todos',
'view' => 'ver',
'owner' => 'due&ntilde;o',

);

?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/es/admin.php <==
<?php

$lan = array(
  'listofadministrators' => 'Lista de administradores',
'Add a new Administrator' => 'A&ntilde;adir administrador',
  'No Access' => 'Sin acceso',
  'Changes saved' => 'Cambios salvados',
  'Error adding new admin' => 'Error al a&ntilde;adir nuevo administrador',
  'strAccessExplain' => '<hr/>
<p class="information">Establecer permisos de acceso a p&aacute;ginas en el sistema:</p>
<ul>
<li>Todos: el administrador tiene acceso a la p&aacute;gina sin restricciones.</li>
<li>Ver: el administrador puede ver la p&aacute;gina, pero no puede cambiar nada. De momento esto solo funciona en las p&aacute;ginas «usuario», «usuarios» y «miembros».</li>
<li>Ninguno: el administrador no puede ver esta p&aacute;gina.</li>
<li>Due&ntilde;o: el administrador puede ver esta p&aacute;gina, pero solo puede ver el contenido de aquellas listas de las que es el due&ntilde;o.</li>
</ul>
',
'Edit Administrator' => 'Editar administrador',
'Admin Details' => 'Detalles de administrador',
'ID' => 'ID',
'Login Name' => 'Nombre de usuario',
'Normalised loginname' => 'Nombre de usuario normalizado',
'Email' => 'Email',
'Time Created' => 'Creado',
'Time modified' => 'Modificado',
'Modified by' => 'Modificado por',
'Last time password was changed' => '&Uacute;ltima vez que se cambi&oacute; la contrase&ntilde;a',
'Is this user Super Admin?' => '&#191;Es superadministrador este usuario?',
'Is this account disabled?' => '&#191;Est&aacute; deshabilitada esta cuenta?',
'Save Changes' => 'Salvar cambios',
'Current set of permissions made default' => 'Se ha establecido la configuraci&oacute;n de
  permisos actual como configuraci&oacute;n por defecto',
'Done' => 'Listo',
'OK' => 'OK',
'Yes' => 'Si',
'No' => 'No',
'Deleting' => 'Borrando',
'Login Name (max 25 chars)' => 'Nombre de usuario (m&aacute;ximo 25 caracteres)',
'Access Details' => 'Ver detalles',
'Access Privileges' => 'Ver privilegios',
'Type' => 'Tipo',
'Page' => 'P&aacute;gina',
'Set these permissions as default' => 'Establecer esta configuraci&oacute;n de permisos como configuraci&oacute;n por defecto',
'Reset to Default' => 'Volver a la configuraci&oacute;n por defecto',
'none' => 'ninguno',
'all' => 'todos',
'view' => 'ver',
'owner' => 'due&ntilde;o',

);

?>
